@@ -105,18 +105,18 @@ test_that("Parameter plots works", {
 
   for(i in 1:length(saved_fits)){
 
-    expect_doppelganger(paste0("plot_theta1_",i),plot(saved_fits[[i]],    "theta",  plot_type = "ggplot"))
+    #expect_doppelganger(paste0("plot_theta1_",i),plot(saved_fits[[i]],    "theta",  plot_type = "ggplot"))
     expect_doppelganger(paste0("plot_forest1_",i),plot(saved_fits[[i]],   "forest", plot_type = "ggplot"))
-    expect_doppelganger(paste0("plot_combined1_",i),plot(saved_fits[[i]], c("theta", "forest"), plot_type = "ggplot"))
+    #expect_doppelganger(paste0("plot_combined1_",i),plot(saved_fits[[i]], c("theta", "forest"), plot_type = "ggplot"))
 
     if(i %in% c(2, 4, 5, 6, 7, 8)){
-      expect_error(plot(saved_fits[[i]],    "theta",  type = "conditional", plot_type = "ggplot"),"The parameter could not be plotted because it is not in the ensemble. Possible cause might be trying to plot a parameter from an ensemble where either no model has the parameters or all of the models did not converge.")
+      #expect_error(plot(saved_fits[[i]],    "theta",  type = "conditional", plot_type = "ggplot"),"The parameter could not be plotted because it is not in the ensemble. Possible cause might be trying to plot a parameter from an ensemble where either no model has the parameters or all of the models did not converge.")
       expect_error(plot(saved_fits[[i]],   "forest", type = "conditional", plot_type = "ggplot"),"The parameter could not be plotted because it is not in the ensemble. Possible cause might be trying to plot a parameter from an ensemble where either no model has the parameters or all of the models did not converge.")
-      expect_error(plot(saved_fits[[i]], c("theta", "forest"), type = "conditional", plot_type = "ggplot"),"The parameter could not be plotted because it is not in the ensemble. Possible cause might be trying to plot a parameter from an ensemble where either no model has the parameters or all of the models did not converge.")
+      #expect_error(plot(saved_fits[[i]], c("theta", "forest"), type = "conditional", plot_type = "ggplot"),"The parameter could not be plotted because it is not in the ensemble. Possible cause might be trying to plot a parameter from an ensemble where either no model has the parameters or all of the models did not converge.")
     }else{
-      expect_doppelganger(paste0("plot_theta2_",i),plot(saved_fits[[i]],    "theta",  type = "conditional", plot_type = "ggplot"))
+      #expect_doppelganger(paste0("plot_theta2_",i),plot(saved_fits[[i]],    "theta",  type = "conditional", plot_type = "ggplot"))
       expect_doppelganger(paste0("plot_forest2_",i),plot(saved_fits[[i]],   "forest", type = "conditional", plot_type = "ggplot"))
-      expect_doppelganger(paste0("plot_combined2_",i),plot(saved_fits[[i]], c("theta", "forest"), type = "conditional", plot_type = "ggplot"))
+      #expect_doppelganger(paste0("plot_combined2_",i),plot(saved_fits[[i]], c("theta", "forest"), type = "conditional", plot_type = "ggplot"))
     }
 
   }
